'use strict';

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Column = exports.Row = exports.GRID_VERTICAL_ALIGNMENTS = exports.GRID_HORIZONTAL_ALIGNMENTS = undefined;

var _react = require('react');

var _styles = require('./styles.scss');

var _styles2 = _interopRequireDefault(_styles);

var _joinObjects = require('../../util/join-objects');

var _joinObjects2 = _interopRequireDefault(_joinObjects);

var _createHigherOrderComponent = require('../../util/create-higher-order-component');

var _createHigherOrderComponent2 = _interopRequireDefault(_createHigherOrderComponent);

var _grid = require('../../util/grid');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var GRID_HORIZONTAL_ALIGNMENTS = exports.GRID_HORIZONTAL_ALIGNMENTS = ['right', 'center', 'justify', 'spaced'];
var GRID_VERTICAL_ALIGNMENTS = exports.GRID_VERTICAL_ALIGNMENTS = ['top', 'middle', 'bottom', 'stretch'];

var rowClassNameToPropMapping = {
  unstack: {
    basePropName: 'Unstack',
    isNumber: false,
    skipSmall: true
  },
  collapse: {
    basePropName: 'Collapse',
    isNumber: false,
    skipSmall: false
  },
  uncollapse: {
    basePropName: 'Uncollapse',
    isNumber: false,
    skipSmall: false
  }
};
var columnClassNameToPropMapping = {
  '': {
    basePropName: '',
    isNumber: true,
    skipSmall: false
  },
  expand: {
    basePropName: 'Expand',
    isNumber: false,
    skipSmall: true
  },
  offset: {
    basePropName: 'Offset',
    isNumber: true,
    skipSmall: false
  },
  order: {
    basePropName: 'Order',
    isNumber: true,
    skipSmall: false
  }
};

var _createGridScreenSize = (0, _grid.createGridScreenSizePropTypes)(rowClassNameToPropMapping, columnClassNameToPropMapping);

var rowPropTypes = _createGridScreenSize.rowPropTypes;
var columnPropTypes = _createGridScreenSize.columnPropTypes;

rowPropTypes.expanded = _react.PropTypes.bool;
rowPropTypes.horizontalAlignment = _react.PropTypes.oneOf(GRID_HORIZONTAL_ALIGNMENTS);
rowPropTypes.verticalAlignment = _react.PropTypes.oneOf(GRID_VERTICAL_ALIGNMENTS);
columnPropTypes.shrink = _react.PropTypes.bool;
columnPropTypes.verticalAlignment = _react.PropTypes.oneOf(GRID_VERTICAL_ALIGNMENTS);

var Row = exports.Row = (0, _createHigherOrderComponent2.default)({
  displayName: 'Row',
  propTypes: rowPropTypes,
  mapPropsToClassNames: function mapPropsToClassNames(_ref) {
    var expanded = _ref.expanded;
    var horizontalAlignment = _ref.horizontalAlignment;
    var verticalAlignment = _ref.verticalAlignment;
    var props = (0, _objectWithoutProperties3.default)(_ref, ['expanded', 'horizontalAlignment', 'verticalAlignment']);

    var classNames = (0, _grid.createScreenSizeClassNamesFromProps)(rowClassNameToPropMapping, props);

    classNames.row = true;
    classNames.expanded = expanded;
    classNames['align-' + horizontalAlignment] = GRID_HORIZONTAL_ALIGNMENTS.includes(horizontalAlignment);
    classNames['align-' + verticalAlignment] = GRID_VERTICAL_ALIGNMENTS.includes(verticalAlignment);

    return (0, _joinObjects2.default)(_styles2.default, classNames);
  },
  defaultComponentClass: 'div',
  collapseOnlyChild: false
});

var Column = exports.Column = (0, _createHigherOrderComponent2.default)({
  displayName: 'Column',
  propTypes: columnPropTypes,
  mapPropsToClassNames: function mapPropsToClassNames(_ref2) {
    var shrink = _ref2.shrink;
    var verticalAlignment = _ref2.verticalAlignment;
    var props = (0, _objectWithoutProperties3.default)(_ref2, ['shrink', 'verticalAlignment']);

    var classNames = (0, _grid.createScreenSizeClassNamesFromProps)(columnClassNameToPropMapping, props);

    classNames.column = true;
    classNames.shrink = shrink;
    classNames['align-' + verticalAlignment] = GRID_VERTICAL_ALIGNMENTS.includes(verticalAlignment);

    return (0, _joinObjects2.default)(_styles2.default, classNames);
  }
});