'use strict';

var _isFinite = require('babel-runtime/core-js/number/is-finite');

var _isFinite2 = _interopRequireDefault(_isFinite);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _values = require('babel-runtime/core-js/object/values');

var _values2 = _interopRequireDefault(_values);

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createGridScreenSizePropTypes = createGridScreenSizePropTypes;
exports.createScreenSizeClassNamesFromProps = createScreenSizeClassNamesFromProps;

var _react = require('react');

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createGridScreenSizePropTypes() {
  var rowMapping = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var columnMapping = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var rowPropTypes = {};
  var columnPropTypes = {};

  _constants.SCREEN_SIZES.forEach(function (size) {
    (0, _values2.default)(rowMapping).forEach(function (_ref) {
      var basePropName = _ref.basePropName;
      var isNumber = _ref.isNumber;
      var skipSmall = _ref.skipSmall;

      if (!skipSmall || !_constants.SMALLER_SCREEN_SIZES.includes(size)) {
        rowPropTypes['' + size + basePropName] = isNumber ? _react.PropTypes.number : _react.PropTypes.bool;
      }
    });

    (0, _values2.default)(columnMapping).forEach(function (_ref2) {
      var basePropName = _ref2.basePropName;
      var isNumber = _ref2.isNumber;
      var skipSmall = _ref2.skipSmall;

      if (!skipSmall || !_constants.SMALLER_SCREEN_SIZES.includes(size)) {
        columnPropTypes['' + size + basePropName] = isNumber ? _react.PropTypes.number : _react.PropTypes.bool;
      }
    });
  });

  return { rowPropTypes: rowPropTypes, columnPropTypes: columnPropTypes };
}

function createScreenSizeClassNamesFromProps() {
  var classNameMapping = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var props = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var classNames = {};

  (0, _keys2.default)(classNameMapping).forEach(function (baseClassName) {
    return _constants.SCREEN_SIZES.forEach(function (size) {
      var _classNameMapping$bas = classNameMapping[baseClassName];
      var basePropName = _classNameMapping$bas.basePropName;
      var isNumber = _classNameMapping$bas.isNumber;

      var propName = '' + size + basePropName;
      var propValue = props[propName];
      var className = size + (baseClassName ? '-' + baseClassName : '');

      if (isNumber) {
        if ((0, _isFinite2.default)(propValue) && propValue >= 0) {
          classNames[className + '-' + propValue] = true;
        }
      } else {
        classNames[className] = propValue;
      }
    });
  });

  return classNames;
}